Documentation
¶
Index ¶
- Variables
- func CurrentTime() time.Time
- func CurrentTimeMs() int64
- func LogHigh() glog.Verbose
- func LogLow() glog.Verbose
- func LogMed() glog.Verbose
- func LogTrace() glog.Verbose
- func SetLogConfig(config *Configuration)
- func SetLogDefaults()
- func TSToTimeIfNotSet(current *time.Time, tsMs *int64) time.Time
- type Configuration
Constants ¶
This section is empty.
Variables ¶
var CurrentStaticTime = time.Time{}
var Version = "dev"
Functions ¶
func CurrentTime ¶
func CurrentTimeMs ¶
func CurrentTimeMs() int64
func SetLogConfig ¶ added in v0.1.3
func SetLogConfig(config *Configuration)
func SetLogDefaults ¶
func SetLogDefaults()
Types ¶
type Configuration ¶
type Configuration struct {
// true if this vault service is the main agency subscriber
// TODO: this need to be rethought when we are scaling vault
AgencyMainSubscriber bool `mapstructure:"agency_main_subscriber"`
AgencyCertPath string `mapstructure:"agency_cert_path"`
AgencyHost string `mapstructure:"agency_host"`
AgencyPort int `mapstructure:"agency_port"`
AgencyAdminID string `mapstructure:"agency_admin_id"`
AgencyInsecure bool `mapstructure:"agency_insecure"`
Address string
DBHost string `mapstructure:"db_host"`
DBPassword string `mapstructure:"db_password"`
DBPort int `mapstructure:"db_port"`
DBTracing bool `mapstructure:"db_tracing"`
DBMigrationsPath string `mapstructure:"db_migrations_path"`
DBName string `mapstructure:"db_name"`
GenerateFakeData bool
JWTKey string `mapstructure:"jwt_key"`
LogLevel string `mapstructure:"log_level"`
ServerPort int `mapstructure:"server_port"`
UsePlayground bool `mapstructure:"use_playground"`
Version string
}
func LoadConfig ¶
func LoadConfig() *Configuration
Click to show internal directories.
Click to hide internal directories.